[FFmpeg-cvslog] avformat/flvenc: write proper timestamps when muxing hevc

Timo Rothenpieler git at videolan.org
Tue Jul 25 14:59:06 EEST 2023


ffmpeg | branch: master | Timo Rothenpieler <timo at rothenpieler.org> | Tue Jul 25 01:46:31 2023 +0200| [f8035bc4260568f9e37b80c23a43f676d7da39c2] | committer: Timo Rothenpieler

avformat/flvenc: write proper timestamps when muxing hevc

> http://git.videolan.org/gitweb.cgi/ffmpeg.git/?a=commit;h=f8035bc4260568f9e37b80c23a43f676d7da39c2
---

 libavformat/flvenc.c | 8 +++++++-
 1 file changed, 7 insertions(+), 1 deletion(-)

diff --git a/libavformat/flvenc.c b/libavformat/flvenc.c
index 335d900415..f6d10f331c 100644
--- a/libavformat/flvenc.c
+++ b/libavformat/flvenc.c
@@ -863,6 +863,9 @@ static int flv_write_packet(AVFormatContext *s, AVPacket *pkt)
     else
         flags_size = 1;
 
+    if (par->codec_id == AV_CODEC_ID_HEVC && pkt->pts != pkt->dts)
+        flags_size += 3;
+
     if (par->codec_id == AV_CODEC_ID_AAC || par->codec_id == AV_CODEC_ID_H264
             || par->codec_id == AV_CODEC_ID_MPEG4 || par->codec_id == AV_CODEC_ID_HEVC
             || par->codec_id == AV_CODEC_ID_AV1 || par->codec_id == AV_CODEC_ID_VP9) {
@@ -998,8 +1001,11 @@ static int flv_write_packet(AVFormatContext *s, AVPacket *pkt)
     } else {
         av_assert1(flags>=0);
         if (par->codec_id == AV_CODEC_ID_HEVC) {
-            avio_w8(pb, FLV_IS_EX_HEADER | PacketTypeCodedFramesX | frametype); // ExVideoTagHeader mode with PacketTypeCodedFramesX
+            int pkttype = (pkt->pts != pkt->dts) ? PacketTypeCodedFrames : PacketTypeCodedFramesX;
+            avio_w8(pb, FLV_IS_EX_HEADER | pkttype | frametype); // ExVideoTagHeader mode with PacketTypeCodedFrames(X)
             avio_write(pb, "hvc1", 4);
+            if (pkttype == PacketTypeCodedFrames)
+                avio_wb24(pb, pkt->pts - pkt->dts);
         } else if (par->codec_id == AV_CODEC_ID_AV1 || par->codec_id == AV_CODEC_ID_VP9) {
             avio_w8(pb, FLV_IS_EX_HEADER | PacketTypeCodedFrames | frametype);
             avio_write(pb, par->codec_id == AV_CODEC_ID_AV1 ? "av01" : "vp09", 4);



More information about the ffmpeg-cvslog mailing list